# BONSAI dataio Python package

This package is part of the [BONSAI database](http://bonsamurais.gitlab.io/bonsai/documentation/) created by the Getting The Data Right project.
The goal of this project is to deliver a global input-output (IO) database of consequential carbon footprints.

You can download the documentation as pdf [here](http://bonsamurais.gitlab.io/bonsai/util/dataio/user_guide.pdf).

## Contents

```{toctree}
:maxdepth: 2

Overview <readme>
Tutorials <tutorials>
Metadata syntax <syntax>
Future developments <future>
Contributions & Help <contributing>
License <license>
Authors <authors>
Changelog <changelog>
Module Reference <api/modules>
```

## Indices and tables

* {ref}`genindex`
* {ref}`modindex`
* {ref}`search`
